@@ -40,7 +40,13 @@ Implementation Notes
 import math
 import analogio
 
-__version__ = "0.0.0-auto.0"
+try:
+    import typing  # pylint: disable=unused-import
+    import microcontroller
+except ImportError:
+    pass
+
+__version__ = "3.4.6"
 __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_Thermistor.git"
 
 
@@ -85,14 +91,14 @@ class Thermistor:
 
     def __init__(
         self,
-        pin,
-        series_resistor,
-        nominal_resistance,
-        nominal_temperature,
-        b_coefficient,
+        pin: microcontroller.Pin,
+        series_resistor: int,
+        nominal_resistance: int,
+        nominal_temperature: int,
+        b_coefficient: int,
         *,
-        high_side=True
-    ):
+        high_side: bool = True
+    ) -> None:
         # pylint: disable=too-many-arguments
         self.pin = analogio.AnalogIn(pin)
         self.series_resistor = series_resistor
@@ -102,7 +108,7 @@ class Thermistor:
         self.high_side = high_side
 
     @property
-    def resistance(self):
+    def resistance(self) -> float:
         """The resistance of the thermistor in Ohms"""
         if self.high_side:
             # Thermistor connected from analog input to high logic level.
@@ -115,7 +121,7 @@ class Thermistor:
         return reading
 
     @property
-    def temperature(self):
+    def temperature(self) -> float:
         """The temperature of the thermistor in Celsius"""
         steinhart = self.resistance / self.nominal_resistance  # (R/Ro)
         steinhart = math.log(steinhart)  # ln(R/Ro)
